"freq.curve.glo" <-
function(fs,para) {
  if(! check.fs(fs)) return()
  if(! is.glo(para)) return()
  Q <- vector(mode="numeric",length = length(fs))
  if(! are.parglo.valid(para)) return(Q)
  for(i in seq(1,length(fs))) {
    Q[i] <- quaglo(fs[i],para)
  }
  return(Q)
}

